diff mbox series

[RFC,2/2] wifi: mac80211: rename cfg80211_rx_assoc_resp() to cfg80211_rx_assoc_response()

Message ID 20231009170120.2522470-2-kvalo@kernel.org
State New
Headers show
Series [RFC,1/2] wifi: mac80211: rename ieee80211_tx_status() to ieee80211_tx_status_skb() | expand

Commit Message

Kalle Valo Oct. 9, 2023, 5:01 p.m. UTC
From: Kalle Valo <quic_kvalo@quicinc.com>

make htmldocs warns:

Documentation/driver-api/80211/cfg80211:48: ./include/net/cfg80211.h:7290: WARNING: Duplicate C declaration, also defined at cfg80211:7251.
Declaration is '.. c:function:: void cfg80211_rx_assoc_resp (struct net_device *dev, struct cfg80211_rx_assoc_resp *data)'.

This is because there's a function named cfg80211_rx_assoc_resp() and a struct
named cfg80211_rx_assoc_resp, see previous patch for more info.

To workaround this rename the function to cfg80211_rx_assoc_response(). The
function name is a bit longer now but still IMHO not too long.

Compile tested only.

Signed-off-by: Kalle Valo <quic_kvalo@quicinc.com>
---
 Documentation/driver-api/80211/cfg80211.rst | 2 +-
 include/net/cfg80211.h                      | 8 ++++----
 net/mac80211/mlme.c                         | 2 +-
 net/wireless/mlme.c                         | 6 +++---
 4 files changed, 9 insertions(+), 9 deletions(-)
diff mbox series

Patch

diff --git a/Documentation/driver-api/80211/cfg80211.rst b/Documentation/driver-api/80211/cfg80211.rst
index 836f609c3f75..66900f3cd102 100644
--- a/Documentation/driver-api/80211/cfg80211.rst
+++ b/Documentation/driver-api/80211/cfg80211.rst
@@ -73,7 +73,7 @@  Actions and configuration
 	cfg80211_pmksa
 	cfg80211_rx_mlme_mgmt
 	cfg80211_auth_timeout
-	cfg80211_rx_assoc_resp
+	cfg80211_rx_assoc_response
 	cfg80211_assoc_timeout
 	cfg80211_tx_mlme_mgmt
 	cfg80211_ibss_joined
diff --git a/net/mac80211/mlme.c b/net/mac80211/mlme.c
index 8d2514a9a6c4..699864da5ae6 100644
--- a/net/mac80211/mlme.c
+++ b/net/mac80211/mlme.c
@@ -5454,7 +5454,7 @@  static void ieee80211_rx_mgmt_assoc_resp(struct ieee80211_sub_if_data *sdata,
 	resp.len = len;
 	resp.req_ies = ifmgd->assoc_req_ies;
 	resp.req_ies_len = ifmgd->assoc_req_ies_len;
-	cfg80211_rx_assoc_resp(sdata->dev, &resp);
+	cfg80211_rx_assoc_response(sdata->dev, &resp);
 notify_driver:
 	drv_mgd_complete_tx(sdata->local, sdata, &info);
 	kfree(elems);
diff --git a/net/wireless/mlme.c b/net/wireless/mlme.c
index 579fea2f3548..418f3d6a4a34 100644
--- a/net/wireless/mlme.c
+++ b/net/wireless/mlme.c
@@ -21,8 +21,8 @@ 
 #include "rdev-ops.h"
 
 
-void cfg80211_rx_assoc_resp(struct net_device *dev,
-			    struct cfg80211_rx_assoc_resp *data)
+void cfg80211_rx_assoc_response(struct net_device *dev,
+				struct cfg80211_rx_assoc_resp *data)
 {
 	struct wireless_dev *wdev = dev->ieee80211_ptr;
 	struct wiphy *wiphy = wdev->wiphy;
@@ -94,7 +94,7 @@  void cfg80211_rx_assoc_resp(struct net_device *dev,
 	/* update current_bss etc., consumes the bss reference */
 	__cfg80211_connect_result(dev, &cr, cr.status == WLAN_STATUS_SUCCESS);
 }
-EXPORT_SYMBOL(cfg80211_rx_assoc_resp);
+EXPORT_SYMBOL(cfg80211_rx_assoc_response);
 
 static void cfg80211_process_auth(struct wireless_dev *wdev,
 				  const u8 *buf, size_t len)
diff --git a/include/net/cfg80211.h b/include/net/cfg80211.h
index a9ef43b33748..0ca208884675 100644
--- a/include/net/cfg80211.h
+++ b/include/net/cfg80211.h
@@ -7271,7 +7271,7 @@  void cfg80211_auth_timeout(struct net_device *dev, const u8 *addr);
 /**
  * struct cfg80211_rx_assoc_resp - association response data
  * @bss: the BSS that association was requested with, ownership of the pointer
  *	moves to cfg80211 in the call to cfg80211_rx_assoc_resp()
  * @buf: (Re)Association Response frame (header + body)
  * @len: length of the frame data
  * @uapsd_queues: bitmap of queues configured for uapsd. Same format
@@ -7299,7 +7299,7 @@  struct cfg80211_rx_assoc_resp {
 };
 
 /**
  * cfg80211_rx_assoc_resp - notification of processed association response
  * @dev: network device
  * @data: association response data, &struct cfg80211_rx_assoc_resp
  *
@@ -7308,8 +7308,8 @@  struct cfg80211_rx_assoc_resp {
  *
  * This function may sleep. The caller must hold the corresponding wdev's mutex.
  */
-void cfg80211_rx_assoc_resp(struct net_device *dev,
-			    struct cfg80211_rx_assoc_resp *data);
+void cfg80211_rx_assoc_response(struct net_device *dev,
+				struct cfg80211_rx_assoc_resp *data);
 
 /**
  * struct cfg80211_assoc_failure - association failure data
@@ -7271,7 +7271,7 @@  void cfg80211_auth_timeout(struct net_device *dev, const u8 *addr);
  * struct cfg80211_rx_assoc_resp - association response data
  * @bss: the BSS that association was requested with, ownership of the pointer
- *	moves to cfg80211 in the call to cfg80211_rx_assoc_resp()
+ *	moves to cfg80211 in the call to cfg80211_rx_assoc_response()
  * @buf: (Re)Association Response frame (header + body)
  * @len: length of the frame data
@@ -7299,7 +7299,7 @@  struct cfg80211_rx_assoc_resp {
 
 /**
- * cfg80211_rx_assoc_resp - notification of processed association response
+ * cfg80211_rx_assoc_response - notification of processed association response
  * @dev: network device
  * @data: association response data, &struct cfg80211_rx_assoc_resp